# Speedcord 
###  A simple discord API wrapper - without all the bullshit 

![GitHub last commit](https://img.shields.io/github/last-commit/tag-epic/speedcord)
![GitHub issues](https://img.shields.io/github/issues-raw/tag-epic/speedcord)
![GitHub pull requests](https://img.shields.io/github/issues-pr/tag-epic/speedcord)
![PyPI downloads](https://img.shields.io/pypi/dm/speedcord)
[![Discord support](https://img.shields.io/discord/759919164872982528)](https://discord.gg/yxrprWz)
[![GitHub license](https://img.shields.io/github/license/TAG-Epic/speedcord)](https://github.com/TAG-Epic/speedcord/blob/master/LICENCE)  


## Installing
You can install Speedcord from PyPi using the following command:

```bash
pip3 install speedcord
```
It is recommended to **pin the version in production to avoid stuff breaking**


## Features
 - Simple sharding for larger bots
 - Speedier requests to the discord API
 - More customizablility


## Usage
There are currently few examples, you are free to contribute new examples

- [Simple command using the `MESSAGE_CREATE` listener](https://github.com/TAG-Epic/speedcord/blob/master/examples/simplecommand.py)
 
## Contributing

Contributions are more than welcome as long as they follow our [contribution guidelines](https://github.com/TAG-Epic/speedcord/blob/master/CONTRIBUTING.md), additonally make sure you follow our [code of conduct](https://github.com/TAG-Epic/speedcord/blob/master/CODE_OF_CONDUCT.md)
